==> japhar-0.04.tar.gz: japhar-0.04/lib/libjni/src/jniref.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   jniref.c -- Java Native Interface methods relating to local or global references.
   Created: Chris Toshok <toshok@hungry.com>, 26-Jul-1997
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
#include "jni.h"
#include "jniint.h"
#include "gc.h"
#include "qop.h"

jobject
JNIFUNC(NewGlobalRef)(JNIEnv *env,
		      jobject obj)
{
  HungryJNIEnv *henv = (HungryJNIEnv*)env;

  UNQUEUE((GC_obj*)obj, henv->_local_refs);
  GC_addReference((JavaVM*)henv->_vm, (GC_obj*)obj);

  return obj;
}

void
JNIFUNC(DeleteGlobalRef)(JNIEnv *env,
			 jobject globalRef)
{
  HungryJNIEnv *henv = (HungryJNIEnv*)env;

  GC_deleteGlobal((JavaVM*)henv->_vm, (GC_obj*)globalRef);
}

void
JNIFUNC(DeleteLocalRef)(JNIEnv *env,
			jobject localRef)
{
  HungryJNIEnv *henv = (HungryJNIEnv*)env;

  UNQUEUE((GC_obj*)localRef, henv->_local_refs);
  GC_finalize((JavaVM*)henv->_vm, (GC_obj*)localRef);
}

==> japhar-0.05.tar.gz: japhar-0.05/lib/libjni/src/jniref.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   jniref.c -- Java Native Interface methods relating to local or global references.
   Created: Chris Toshok <toshok@hungry.com>, 26-Jul-1997
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
#include "jni.h"
#include "jniint.h"
#include "gc.h"
#include "qop.h"

jobject
JNIFUNC(NewGlobalRef)(JNIEnv *env,
		      jobject obj)
{
  HungryJNIEnv *henv = (HungryJNIEnv*)env;
  japhar_object *jobj;

  obj_to_object(obj, jobj);

  UNQUEUE((GC_obj*)jobj, henv->_local_refs);
  GC_addReference((JavaVM*)henv->_vm, (GC_obj*)jobj);

  return obj;
}

void
JNIFUNC(DeleteGlobalRef)(JNIEnv *env,
			 jobject globalRef)
{
  HungryJNIEnv *henv = (HungryJNIEnv*)env;
  japhar_object *jobj;

  obj_to_object(globalRef, jobj);

  GC_deleteGlobal((JavaVM*)henv->_vm, (GC_obj*)jobj);
}

void
JNIFUNC(DeleteLocalRef)(JNIEnv *env,
			jobject localRef)
{
  HungryJNIEnv *henv = (HungryJNIEnv*)env;

  japhar_object *jobj;

  obj_to_object(localRef, jobj);

  UNQUEUE((GC_obj*)jobj, henv->_local_refs);
  GC_finalize((JavaVM*)henv->_vm, (GC_obj*)jobj);
}
